// This sketch demonstrates a number of features 
// related to the display and processing of text,
// all wrapped up in the form of a very simple
// word processor with persistence (i.e., it reloads
// your last saved file when you restart the 
// sketch).

String txt = "";

void setup()
{
  size( 500, 500 );
  textSize( 30 );
  
  // Persistence -- if there's a saved copy of the user's
  // document, restore it now.
  String[] lines = loadStrings( "output.txt" );
  if( lines != null ) {
    txt = join( lines, "\n" );
  }
}

void draw()
{
  background( 50 );
  text( txt, 5, 40 );
}

void keyPressed()
{
  if ( keyCode == BACKSPACE ) {
    // We need to do something special to catch the 
    // backspace key, and remove the last character
    // stored in the string.  We also have to make 
    // sure the string *has* characters in it --
    // taking a substring of an empty string is an error!
    if ( txt.length() > 0 ) {
      txt = txt.substring( 0, txt.length() - 1 );
    }
  } else if( key != CODED ) {
    // This is a bit tricky.  If I want to type a capital
    // letter, I hold down Shift and type a letter.  But
    // the Shift key itself would generate a keyPressed()
    // event that we'd try to store in the document!
    // The condition (key != CODED) above ensures that
    // we only add real text to the String we're building.
    txt = txt + key;
  }
}

// Use a mouse press to save the document to disc.  Soon
// we'll see better ways to do this.
void mousePressed()
{
  PrintWriter out = createWriter( "output.txt" );
  out.print( txt );
  out.flush();
  out.close();
}